# Azure TTS Manager

Minimal Python Text-to-Speech manager using Azure Cognitive Services.
Makes Azure Text-to-Speech just a little more simple. 
Plays speech directly to speakers (no audio files).

## Requirements
- Python 3.10+
- Azure Speech subscription key
- azure-cognitiveservices-speech

## basic usage
```py
manager = tts_manager("replace_witch_your_api_key", "northeurope")
manager.speak("Saying text out loud")
```
```py
manager = tts_manager(os.getenv("AZURE_TTS_KEY"), "northeurope")
asyncio.run(manager.speak_async_prefix("(shouting) Saying text out loud"))
```